# rmtoo-pricing-graph

NAME
SYNOPSIS
DESCRIPTION
OPTIONS
FILES
ENVIRONMENT
SEE ALSO
LIMITATIONS
AUTHOR
COPYRIGHT

## NAME

rmtoo-pricing-graph - requirements management tool: draw pricing graph

## SYNOPSIS

rmtoo-pricing-graph csvfile dotfile

## DESCRIPTION

The rmtoo-pricing-graph is a part of the rmtoo requirment management tool. It reads in a csv file and creates a graph (dot) file.

## OPTIONS

csvfile

The input file for this tool. Please see section FILES for further information.

dotfile

The graph output file int dot format.

## FILES

The input cvs file must be comma seperated file. This file is the results sheet of the oopricing1 output module saved as a cvs file.

## ENVIRONMENT

This tool does not need any other input than the cvs file. This also means, that there is no check done against existing requirements.

## SEE ALSO

rmtoo(7) - overview of rmtoo including all references to available documentation.

## LIMITATIONS

No checks against existing (original) requirements are made.

## AUTHOR

Written by Andreas Florath (rmtoo@florath.net)

## COPYRIGHT

Copyright © 2010 by flonatel (rmtoo@florath.net). License GPLv3+: GNU GPL version 3 or later